@@ -120,7 +120,7 @@ create_notification_action (NdNotificationBox *box,
         gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
         gtk_container_set_border_width (GTK_CONTAINER (button), 0);
 
-        hbox = gtk_hbox_new (FALSE, 6);
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
         gtk_widget_show (hbox);
         gtk_container_add (GTK_CONTAINER (button), hbox);
 
@@ -143,14 +143,15 @@ create_notification_action (NdNotificationBox *box,
                                      text);
                 gtk_widget_show (image);
                 gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-                gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.5);
+                gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
+                gtk_widget_set_valign (image, GTK_ALIGN_CENTER);
         } else {
                 GtkWidget *label;
 
                 label = gtk_label_new (NULL);
                 gtk_widget_show (label);
                 gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-                gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+                gtk_label_set_xalign (GTK_LABEL (label), 0.0);
                 buf = g_strdup_printf ("<small>%s</small>", text);
                 gtk_label_set_markup (GTK_LABEL (label), buf);
                 g_free (buf);
@@ -210,7 +211,7 @@ update_notification_box (NdNotificationBox *notification_box)
         gtk_label_set_markup (GTK_LABEL (notification_box->priv->summary_label), str);
         g_free (str);
 
-        gtk_widget_size_request (notification_box->priv->close_button, &req);
+        gtk_widget_get_preferred_size (notification_box->priv->close_button, NULL, &req);
         /* -1: main_vbox border width
            -10: vbox border width
            -6: spacing for hbox */
@@ -274,10 +275,9 @@ nd_notification_box_init (NdNotificationBox *notification_box)
         GtkWidget     *vbox;
         GtkWidget     *alignment;
         AtkObject     *atkobj;
-        GtkRcStyle    *rcstyle;
 
         notification_box->priv = ND_NOTIFICATION_BOX_GET_PRIVATE (notification_box);
-        box = gtk_hbox_new (FALSE, 6);
+        box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
         gtk_container_add (GTK_CONTAINER (notification_box), box);
         gtk_widget_show (box);
 
@@ -295,7 +295,7 @@ nd_notification_box_init (NdNotificationBox *notification_box)
         gtk_widget_show (notification_box->priv->icon);
         gtk_container_add (GTK_CONTAINER (iconbox), notification_box->priv->icon);
 
-        vbox = gtk_vbox_new (FALSE, 6);
+        vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
         gtk_widget_show (vbox);
         gtk_box_pack_start (GTK_BOX (box), vbox, TRUE, TRUE, 0);
         gtk_container_set_border_width (GTK_CONTAINER (vbox), 10);
@@ -315,18 +315,13 @@ nd_notification_box_init (NdNotificationBox *notification_box)
                           G_CALLBACK (on_close_button_clicked),
                           notification_box);
 
-        rcstyle = gtk_rc_style_new ();
-        rcstyle->xthickness = rcstyle->ythickness = 0;
-        gtk_widget_modify_style (notification_box->priv->close_button, rcstyle);
-        g_object_unref (rcstyle);
-
         atkobj = gtk_widget_get_accessible (notification_box->priv->close_button);
         atk_action_set_description (ATK_ACTION (atkobj), 0,
                                     "Closes the notification.");
         atk_object_set_name (atkobj, "");
         atk_object_set_description (atkobj, "Closes the notification.");
 
-        image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
+        image = gtk_image_new_from_icon_name ("window-close", GTK_ICON_SIZE_MENU);
         gtk_widget_show (image);
         gtk_container_add (GTK_CONTAINER (notification_box->priv->close_button), image);
 
@@ -334,18 +329,19 @@ nd_notification_box_init (NdNotificationBox *notification_box)
         notification_box->priv->summary_label = gtk_label_new (NULL);
         gtk_widget_show (notification_box->priv->summary_label);
         gtk_box_pack_start (GTK_BOX (vbox), notification_box->priv->summary_label, TRUE, TRUE, 0);
-        gtk_misc_set_alignment (GTK_MISC (notification_box->priv->summary_label), 0, 0);
+        gtk_label_set_xalign (GTK_LABEL (notification_box->priv->summary_label), 0.0);
+        gtk_label_set_yalign (GTK_LABEL (notification_box->priv->summary_label), 0.0);
         gtk_label_set_line_wrap (GTK_LABEL (notification_box->priv->summary_label), TRUE);
         gtk_label_set_line_wrap_mode (GTK_LABEL (notification_box->priv->summary_label), PANGO_WRAP_WORD_CHAR);
 
         atkobj = gtk_widget_get_accessible (notification_box->priv->summary_label);
         atk_object_set_description (atkobj, "Notification summary text.");
 
-        notification_box->priv->content_hbox = gtk_hbox_new (FALSE, 6);
+        notification_box->priv->content_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
         gtk_widget_show (notification_box->priv->content_hbox);
         gtk_box_pack_start (GTK_BOX (vbox), notification_box->priv->content_hbox, FALSE, FALSE, 0);
 
-        vbox = gtk_vbox_new (FALSE, 6);
+        vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 
         gtk_widget_show (vbox);
         gtk_box_pack_start (GTK_BOX (notification_box->priv->content_hbox), vbox, TRUE, TRUE, 0);
@@ -353,7 +349,8 @@ nd_notification_box_init (NdNotificationBox *notification_box)
         notification_box->priv->body_label = gtk_label_new (NULL);
         gtk_widget_show (notification_box->priv->body_label);
         gtk_box_pack_start (GTK_BOX (vbox), notification_box->priv->body_label, TRUE, TRUE, 0);
-        gtk_misc_set_alignment (GTK_MISC (notification_box->priv->body_label), 0, 0);
+        gtk_label_set_xalign (GTK_LABEL (notification_box->priv->body_label), 0.0);
+        gtk_label_set_yalign (GTK_LABEL (notification_box->priv->body_label), 0.0);
         gtk_label_set_line_wrap (GTK_LABEL (notification_box->priv->body_label), TRUE);
         gtk_label_set_line_wrap_mode (GTK_LABEL (notification_box->priv->body_label), PANGO_WRAP_WORD_CHAR);
 
@@ -364,7 +361,7 @@ nd_notification_box_init (NdNotificationBox *notification_box)
         gtk_widget_show (alignment);
         gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, TRUE, 0);
 
-        notification_box->priv->actions_box = gtk_hbox_new (FALSE, 6);
+        notification_box->priv->actions_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
         gtk_widget_show (notification_box->priv->actions_box);
         gtk_container_add (GTK_CONTAINER (alignment), notification_box->priv->actions_box);
 
