@@ -194,6 +194,8 @@ nd_notification_update (NdNotification *notification,
                                      value); /* steals value */
         }
 
+        notification->timeout = timeout;
+
         g_signal_emit (notification, signals[CHANGED], 0);
 
         g_get_current_time (&notification->update_time);
@@ -243,6 +245,8 @@ hint_to_boolean (NdNotification *notification,
                 return TRUE;
         } else if (g_variant_is_of_type (value, G_VARIANT_TYPE_BYTE)) {
                 return (g_variant_get_byte (value) != 0);
+        } else if (g_variant_is_of_type (value, G_VARIANT_TYPE_BOOLEAN)) {
+                return g_variant_get_boolean (value);
         } else {
                 g_assert_not_reached ();
         }
@@ -324,6 +328,13 @@ nd_notification_get_icon (NdNotification *notification)
         return notification->icon;
 }
 
+int
+nd_notification_get_timeout (NdNotification *notification)
+{
+        g_return_val_if_fail (ND_IS_NOTIFICATION (notification), -1);
+
+        return notification->timeout;
+}
 
 static GdkPixbuf *
 scale_pixbuf (GdkPixbuf *pixbuf,
@@ -488,7 +499,7 @@ nd_notification_load_image (NdNotification *notification,
                 pixbuf = _notify_daemon_pixbuf_from_data_hint (data, size);
         } else if ((data = (GVariant *) g_hash_table_lookup (notification->hints, "image-path"))
                    || (data = (GVariant *) g_hash_table_lookup (notification->hints, "image_path"))) {
-                if (g_variant_is_of_type (data, G_VARIANT_TYPE ("(s)"))) {
+                if (g_variant_is_of_type (data, G_VARIANT_TYPE_STRING)) {
                         const char *path;
                         path = g_variant_get_string (data, NULL);
                         pixbuf = _notify_daemon_pixbuf_from_path (path, size);
